import createHead from './components/header.js';
import createTasks from './components/tasks.js';
import createFooter from './components/footer.js';

require('todomvc-app-css/index.css');

function app(container) {
  let id = 0;
  const model = {
    tasks: []
  };

  const header = createHead();
  const body = createTasks(model.tasks);
  const footer = createFooter();

  header.render(container);
  body.render(container);
  footer.render(container);

  header.on('create', (el) => {
    const newTask = { id: id++, label: el, completed: false };
    body.addTask(newTask);
  });

  // set default filter for default route
  body.filter(() => true);
  footer.setActiveRoute('all');

  footer.on('clear-completed', () => {
    body.clearCompleted();
  });

  // If list of tasks is updated count and display completed
  body.on('updated', () => {
    footer.setCounter(model.tasks.reduce((result, element) => {
      if (!element.completed) {
        return result + 1;
      }
      return result;
    }, 0));
  });

  // Router
  window.addEventListener('hashchange', () => {
    const route = location.hash.substr(2) || 'all';
    footer.setActiveRoute(route);

    if (route === 'active') {
      return body.filter((task) => !task.completed);
    }
    if (route === 'completed') {
      return body.filter((task) => task.completed);
    }

    // display all
    body.filter(() => true);
  });
}

const container = document.getElementById('container');
app(container);
