/*
 * This is very simple event emitter.
 */

function on(event, func) {
  const _listeners = this._listeners;
  if (!_listeners.hasOwnProperty(event)) {
    _listeners[event] = [];
  }
  _listeners[event].push(func);
}

function off(event, func) {
  const eventListeners = this._listeners[event];
  if (eventListeners !== undefined) {
    const idx = eventListeners.indexOf(func);
    if (idx !== -1) {
      eventListeners.splice(idx, 1);
    }
  }
}

function trigger(event, data) {
  const eventListeners = this._listeners[event];
  if (eventListeners !== undefined) {
    const len = eventListeners.length;
    for (let i = 0; i < len; i++) {
      eventListeners[i](data);
    }
  }
}

function removeAll() {
  this._listeners = {};
}

export default function createEmitter() {
  return {
    _listeners: {},
    on, off,
    trigger,
    removeAll
  };
}
