/* eslint-disable no-console, new-cap */
const tar = require('tar');
const fstream = require('fstream');
const fs = require('fs');
const zlib = require('zlib');

function filter() {
  return !this.basename.match(/^node_modules$/) &&
    !this.basename.match(/\.tar\.gz$/) &&
    !this.basename.match(/\.hg$/);
}

function buildNPMPackage(input, version) {
  const ver = version !== '' ? '-' + version : '';
  const fName = `redom${ver}.tar.gz`;
  const output = fs.createWriteStream(fName);

  console.log('Building', input, '->', fName);

  function onError(err) {
    console.error('An error occurred:', err);
  }

  function onEnd() {
    console.log('Packed!', version);
  }

  const packer = tar.Pack({ noProprietary: true })
    .on('error', onError)
    .on('end', onEnd);

  // This must be a 'directory'
  fstream.Reader({ path: input, type: 'Directory', filter })
    .on('error', onError)
    .pipe(packer)
    .pipe(zlib.createGzip())
    .pipe(output);
}


if (process.argv.length < 3) {
  console.error('Usage: node build.js folder [version]');
  process.exit(1);
}

if (process.env.npm_package_version) {
  buildNPMPackage(process.argv[2], process.env.npm_package_version);
} else if (process.argv.length === 4) {
  buildNPMPackage(process.argv[2], process.argv[3]);
} else {
  buildNPMPackage(process.argv[2]);
}
